==> koffice-trinity-3.5.13.2.tar.xz: koffice-trinity-3.5.13.2/kivio/kiviopart/kivio_factory.h <==
/*
 * Kivio - Visual Modelling and Flowcharting
 * Copyright (C) 2000-2001 theKompany.com & Dave Marotti
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef KIVIO_FACTORY_H
#define KIVIO_FACTORY_H

#include <KoFactory.h>
#include <koffice_export.h>
class KInstance;
class KAboutData;

class KIVIO_EXPORT KivioFactory : public KoFactory
{ Q_OBJECT
  TQ_OBJECT
public:
  KivioFactory( TQObject* parent = 0, const char* name = 0 );
  ~KivioFactory();

  virtual KParts::Part *createPartObject( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const TQStringList &args = TQStringList() );

  static KInstance* global();
  static KAboutData* aboutData();

private:
  static KInstance* s_global;
  static KAboutData* s_aboutData;
};

#endif

==> koffice-trinity_14.1.0.orig.tar.xz: koffice-trinity-14.1.0/kivio/kiviopart/kivio_factory.h <==
/*
 * Kivio - Visual Modelling and Flowcharting
 * Copyright (C) 2000-2001 theKompany.com & Dave Marotti
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef KIVIO_FACTORY_H
#define KIVIO_FACTORY_H

#include <KoFactory.h>
#include <koffice_export.h>
class TDEInstance;
class TDEAboutData;

class KIVIO_EXPORT KivioFactory : public KoFactory
{ Q_OBJECT
  
public:
  KivioFactory( TQObject* parent = 0, const char* name = 0 );
  ~KivioFactory();

  virtual KParts::Part *createPartObject( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const TQStringList &args = TQStringList() );

  static TDEInstance* global();
  static TDEAboutData* aboutData();

private:
  static TDEInstance* s_global;
  static TDEAboutData* s_aboutData;
};

#endif
